Welcome to linna's documentation!
======================================
.. toctree::
   :maxdepth: 2
   :caption: Example
   :hidden:
   ./notebooks/multivariate_gaussian_distribution.ipynb
   ./notebooks/cosmolike_3x2pt_analyese.ipynb

.. toctree::
   :maxdepth: 1
   :glob:

   readme
   installation
   example
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
